@@ -1,8 +1,12 @@
 from .logger_impl import LoggerImpl
 from .logger_interface import LoggerInterface
+import copy
 
 class CompositeLogger(LoggerImpl):
-    def __init__(self, config = {}):
+    def __init__(self, config = None):
+        if config is None:
+            config = {}
+
         if "loggerFilterPairs" not in config:
             config["loggerFilterPairs"] = []
         if "defaults" not in config:
@@ -11,10 +15,13 @@ class CompositeLogger(LoggerImpl):
         self.config = config
 
 
-    def log(self, message: dict, option: dict = {}):
+    def log(self, message: dict, option: dict = None):
+        if option is None:
+            option = {}
+
         mergedMessage = {}
         if len(self.config["defaults"]) > 0:
-            mergedMessage: dict = self.config["defaults"].copy()
+            mergedMessage: dict = copy.deepcopy(self.config["defaults"])
             for k, v in mergedMessage.items():
                 if callable(v):
                     v()
