@@ -4,7 +4,9 @@ import json
 
 class FileLogger(LoggerImpl):
 
-    def __init__(self, config: dict = {}):
+    def __init__(self, config: dict = None):
+        if config is None:
+            config = {}
 
         if "truncate" not in config:
             config["truncate"] = False
@@ -15,6 +17,9 @@ class FileLogger(LoggerImpl):
 
         self.config = config
 
-    def log(self, message: dict, option: dict = {}):
+    def log(self, message: dict, option: dict = None):
+        if option is None:
+            option = {}
+
         with open(self.config["filePath"], 'a') as file:
             file.write(json.dumps(message) + "\n")
\ No newline at end of file
