@@ -6,7 +6,7 @@ class MemoryLogger(LoggerImpl):
     def __init__(self):
         self.logs = []
 
-    def log(self, message: dict, option: dict = {}):
+    def log(self, message: dict, option: dict = None):
         self.logs.append(message)
 
     def getInMomory(self):
