@@ -3,5 +3,5 @@ from .logger_impl import LoggerImpl
 
 class NullLogger(LoggerImpl):
 
-    def log(message: dict, option: dict = {}):
+    def log(message: dict, option: dict = None):
         pass
\ No newline at end of file
